==> 0.0.2.tar.gz: lib/waves_crypto.dart <==
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/services.dart';
import 'package:waves_sdk/models/key_pair.dart';

///
/// https://github.com/wavesplatform/WavesSDK-android/wiki/Waves-Crypto
/// 
class WavesCrypto {
  static const MethodChannel _channel = const MethodChannel('waves_crypto');

  static Future<KeyPair> keyPair(String seed) async {
    final result = await _channel.invokeMethod('keyPair', seed);
    print(result);
    return KeyPair(result['publicKey'], result['privateKey']);
  }

  static Future<String> publicKey(String seed) async {
    return await _channel.invokeMethod('publicKey', seed);
  }

  static Future<String> privateKey(String seed) async {
    return await _channel.invokeMethod('privateKey', seed);
  }

  static Future<String> addressByPublicKey(String publicKey) async {
    return await _channel.invokeMethod('addressByPublicKey', publicKey);
  }

  static Future<String> addressBySeed(String seed) async {
    return await _channel.invokeMethod('addressBySeed', seed);
  }

  static Future<String> randomSeed() async {
    return await _channel.invokeMethod('randomSeed');
  }

  static Future<Uint8List> signBytesWithPrivateKey(Uint8List bytes, String privateKey) async {
    final result = await _channel.invokeMethod('signBytesWithPrivateKey', {'bytes': bytes, 'privateKey': privateKey});
    return Uint8List(result);
  }

  static Future<Uint8List> signBytesWithSeed(Uint8List bytes, String seed) async {
    final result = await _channel.invokeMethod('signBytesWithSeed', {'bytes': bytes, 'seed': seed});
    return Uint8List(result);
  }

  static Future<bool> verifySignature(String publicKey, Uint8List bytes, Uint8List signature) async {
    return await _channel.invokeMethod('verifySignature', {'publicKey': publicKey, 'bytes': bytes, 'signature': signature});
  }

  static Future<bool> verifyPublicKey(String publicKey) async {
    return await _channel.invokeMethod('verifyPublicKey', publicKey);
  }

  static Future<bool> verifyAddress(String address, {String publicKey}) async {
    return await _channel.invokeMethod('verifyAddress', {'address': address, 'publicKey': publicKey});
  }
}

==> 0.1.3.tar.gz: lib/waves_crypto.dart <==
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/services.dart';
import 'package:waves_sdk/models/key_pair.dart';

///
/// https://github.com/wavesplatform/WavesSDK-android/wiki/Waves-Crypto
/// 
class WavesCrypto {
  static const MethodChannel _channel = const MethodChannel('waves_crypto');

  static Future<KeyPair> keyPair(String seed) async {
    final result = await _channel.invokeMethod('keyPair', seed);
    return KeyPair(result['publicKey'], result['privateKey']);
  }

  static Future<String> publicKey(String seed) async {
    return await _channel.invokeMethod('publicKey', seed);
  }

  static Future<String> privateKey(String seed) async {
    return await _channel.invokeMethod('privateKey', seed);
  }

  static Future<String> addressByPublicKey(String publicKey) async {
    return await _channel.invokeMethod('addressByPublicKey', publicKey);
  }

  static Future<String> addressBySeed(String seed) async {
    return await _channel.invokeMethod('addressBySeed', seed);
  }

  static Future<String> randomSeed() async {
    return await _channel.invokeMethod('randomSeed');
  }

  static Future<Uint8List> signBytesWithPrivateKey(Uint8List bytes, String privateKey) async {
    return await _channel.invokeMethod('signBytesWithPrivateKey', {'bytes': bytes, 'privateKey': privateKey});
  }

  static Future<Uint8List> signBytesWithSeed(Uint8List bytes, String seed) async {
    return await _channel.invokeMethod('signBytesWithSeed', {'bytes': bytes, 'seed': seed});
  }

  static Future<bool> verifySignature(String publicKey, Uint8List bytes, Uint8List signature) async {
    return await _channel.invokeMethod('verifySignature', {'publicKey': publicKey, 'bytes': bytes, 'signature': signature});
  }

  static Future<bool> verifyPublicKey(String publicKey) async {
    return await _channel.invokeMethod('verifyPublicKey', publicKey);
  }

  static Future<bool> verifyAddress(String address, {String publicKey}) async {
    return await _channel.invokeMethod('verifyAddress', {'address': address, 'publicKey': publicKey});
  }
}
